==> kdesvn-1.7.0.tar.xz: kdesvn-1.7.0/src/svnfrontend/opencontextmenu.h <==
/***************************************************************************
 *   Copyright (C) 2006-2009 by Rajko Albrecht                             *
 *   ral@alwins-world.de                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef OPENCONTEXTMENU_H
#define OPENCONTEXTMENU_H

#include <kservice.h>
#include <kaction.h>
#include <kurl.h>
#include <kmenu.h>

#include <QMap>

/**
    @author Rajko Albrecht <ral@alwins-world.de>
*/
class OpenContextmenu : public KMenu
{
    Q_OBJECT
public:
    OpenContextmenu(const KUrl &aPath, const KService::List &aList, QWidget *parent);
    virtual ~OpenContextmenu();
protected:
    KUrl m_Path;
    KService::List m_List;
    QMap<int, KService::Ptr> m_mapPopup;

    void setup();

protected slots:
    virtual void slotOpenWith();
    virtual void slotRunService(QAction *);
};

#endif

==> kdesvn_2.1.0.orig.tar.xz: kdesvn-2.1.0/src/svnfrontend/opencontextmenu.h <==
/***************************************************************************
 *   Copyright (C) 2006-2009 by Rajko Albrecht                             *
 *   ral@alwins-world.de                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#pragma once

#include <KService>

#include <QMenu>
#include <QUrl>
#include <QVector>

/**
    @author Rajko Albrecht <ral@alwins-world.de>
*/
class OpenContextmenu : public QMenu
{
    Q_OBJECT
public:
    OpenContextmenu(const QUrl &aPath, const KService::List &aList, QWidget *parent);
    ~OpenContextmenu();
protected:
    QUrl m_Path;
    KService::List m_List;
    QVector<KService::Ptr> m_mapPopup;

    void setup();

protected Q_SLOTS:
    void slotOpenWith();
    void slotRunService(QAction *);
};
